==> nextcloud-24.0.10.tgz: nextcloud/apps/encryption/l10n/ro.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Lipsește parola cheii de recuperare",
    "Please repeat the recovery key password" : "Te rog repetă parola cheii de recuperare",
    "Repeated recovery key password does not match the provided recovery key password" : "Parolele cheii de recuperare nu se potrivesc",
    "Recovery key successfully enabled" : "Cheia de recuperare a fost activată cu succes",
    "Could not enable recovery key. Please check your recovery key password!" : "Nu s-a putut activa cheia de recuperare. Verifică-ți parola de recuperare!",
    "Recovery key successfully disabled" : "Cheia de recuperare dezactivată cu succes",
    "Could not disable recovery key. Please check your recovery key password!" : "Nu s-a putut dezactiva cheia de recuperare. Verifică-ți parola cheii de recuperare!",
    "Missing parameters" : "Parametri lipsă",
    "Please provide the old recovery password" : "Te rog oferă parola de recuperare veche",
    "Please provide a new recovery password" : "Te rog oferă o nouă parolă de recuperare",
    "Please repeat the new recovery password" : "Te rog repetă noua parolă de recuperare",
    "Password successfully changed." : "Parola a fost modificată cu succes.",
    "Could not change the password. Maybe the old password was not correct." : "Parola nu a putut fi schimbată. Poate ca parola veche este incorectă.",
    "Recovery Key disabled" : "Cheia de recuperare a fost dezactivată",
    "Recovery Key enabled" : "Cheie de recuperare activată",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nu poate fi activată cheia de recuperare, te rog încearcă din nou sau contactează administratorul",
    "Could not update the private key password." : "Nu a putut fi actualizată parola cheii private.",
    "The old password was not correct, please try again." : "Parola veche nu este cea corectă, încearcă din nou.",
    "The current log-in password was not correct, please try again." : "Parola curentă de autentificare nu este corectă, încearcă din nou.",
    "Private key password successfully updated." : "Parola cheii private a fost actualizată cu succes.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Cheie privată invalidă pentru aplicația de criptare. Actualizează-ți parola cheii private folosind setările personale pentru a redobândi accesul la fișierele tale criptate.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Aplicația de criptare este activată dar cheile nu sunt inițializate, te rugăm, reautentifică-te.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Vă rugăm să abilitați criptarea pe server in setarile de administrator ca să folosiți modul de criptare.",
    "Encryption app is enabled and ready" : "Aplicația de criptare este activată",
    "Bad Signature" : "Semnătură greșită",
    "Missing Signature" : "Semnătură lipsă",
    "Default encryption module" : "Modulul implicit de criptare",
    "Default encryption module for server-side encryption" : "Modulul implicit de criptare pentru criptarea pe server",
    "The share will expire on %s." : "Partajarea va expira în data de %s.",
    "Cheers!" : "Noroc!",
    "Enable recovery key" : "Activează cheia de recuperare",
    "Disable recovery key" : "Dezactivează cheia de recuperare",
    "Recovery key password" : "Parola cheii de recuperare",
    "Repeat recovery key password" : "Repetă parola cheii de recuperare",
    "Change recovery key password:" : "Schimbă parola cheii de recuperare:",
    "Old recovery key password" : "Parola veche a cheii de recuperare",
    "New recovery key password" : "Parola nouă a cheii de recuperare",
    "Repeat new recovery key password" : "Repetă parola nouă a cheii de recuperare",
    "Change Password" : "Schimbă parola",
    "Your private key password no longer matches your log-in password." : "Parola cheii tale private nu se mai potrivește cu parola pentru autentificare.",
    "Old log-in password" : "Parola veche pentru autentificare",
    "Current log-in password" : "Parola curentă pentru autentificare",
    "Update Private Key Password" : "Actualizează parola cheii private",
    "Enable password recovery:" : "Activează recuperarea parolei:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Activarea acestei opțiuni îți va permite să redobândești accesul la fișierele tale criptate în cazul pierderii parolei",
    "Enabled" : "Activat",
    "Disabled" : "Dezactivat"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-25.0.8.tgz: nextcloud/apps/encryption/l10n/ro.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Lipsește parola cheii de recuperare",
    "Please repeat the recovery key password" : "Te rog repetă parola cheii de recuperare",
    "Repeated recovery key password does not match the provided recovery key password" : "Parolele cheii de recuperare nu se potrivesc",
    "Recovery key successfully enabled" : "Cheia de recuperare a fost activată cu succes",
    "Could not enable recovery key. Please check your recovery key password!" : "Nu s-a putut activa cheia de recuperare. Verifică-ți parola de recuperare!",
    "Recovery key successfully disabled" : "Cheia de recuperare dezactivată cu succes",
    "Could not disable recovery key. Please check your recovery key password!" : "Nu s-a putut dezactiva cheia de recuperare. Verifică-ți parola cheii de recuperare!",
    "Missing parameters" : "Parametri lipsă",
    "Please provide the old recovery password" : "Te rog oferă parola de recuperare veche",
    "Please provide a new recovery password" : "Te rog oferă o nouă parolă de recuperare",
    "Please repeat the new recovery password" : "Te rog repetă noua parolă de recuperare",
    "Password successfully changed." : "Parola a fost modificată cu succes.",
    "Could not change the password. Maybe the old password was not correct." : "Parola nu a putut fi schimbată. Poate ca parola veche este incorectă.",
    "Recovery Key disabled" : "Cheia de recuperare a fost dezactivată",
    "Recovery Key enabled" : "Cheie de recuperare activată",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nu poate fi activată cheia de recuperare, te rog încearcă din nou sau contactează administratorul",
    "Could not update the private key password." : "Nu a putut fi actualizată parola cheii private.",
    "The old password was not correct, please try again." : "Parola veche nu este cea corectă, încearcă din nou.",
    "The current log-in password was not correct, please try again." : "Parola curentă de autentificare nu este corectă, încearcă din nou.",
    "Private key password successfully updated." : "Parola cheii private a fost actualizată cu succes.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Cheie privată invalidă pentru aplicația de criptare. Actualizează-ți parola cheii private folosind setările personale pentru a redobândi accesul la fișierele tale criptate.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Aplicația de criptare este activată dar cheile nu sunt inițializate, te rugăm, reautentifică-te.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Vă rugăm să abilitați criptarea pe server in setarile de administrator ca să folosiți modul de criptare.",
    "Encryption app is enabled and ready" : "Aplicația de criptare este activată",
    "Bad Signature" : "Semnătură greșită",
    "Missing Signature" : "Semnătură lipsă",
    "Default encryption module" : "Modulul implicit de criptare",
    "Default encryption module for server-side encryption" : "Modulul implicit de criptare pentru criptarea pe server",
    "Enable recovery key" : "Activează cheia de recuperare",
    "Disable recovery key" : "Dezactivează cheia de recuperare",
    "Recovery key password" : "Parola cheii de recuperare",
    "Repeat recovery key password" : "Repetă parola cheii de recuperare",
    "Change recovery key password:" : "Schimbă parola cheii de recuperare:",
    "Old recovery key password" : "Parola veche a cheii de recuperare",
    "New recovery key password" : "Parola nouă a cheii de recuperare",
    "Repeat new recovery key password" : "Repetă parola nouă a cheii de recuperare",
    "Change Password" : "Schimbă parola",
    "Your private key password no longer matches your log-in password." : "Parola cheii tale private nu se mai potrivește cu parola pentru autentificare.",
    "Old log-in password" : "Parola veche pentru autentificare",
    "Current log-in password" : "Parola curentă pentru autentificare",
    "Update Private Key Password" : "Actualizează parola cheii private",
    "Enable password recovery:" : "Activează recuperarea parolei:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Activarea acestei opțiuni îți va permite să redobândești accesul la fișierele tale criptate în cazul pierderii parolei",
    "Enabled" : "Activat",
    "Disabled" : "Dezactivat",
    "The share will expire on %s." : "Partajarea va expira în data de %s.",
    "Cheers!" : "Noroc!"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
